censored_words_rus = (
    # Основные слова
    'блядь', 'блять', 'бля', 'блядина', 'блядки', 'блядовать',
    'сука', 'сучка', 'сучара', 'сучонка',
    'пидор', 'пидорас', 'пидарас', 'педик', 'педрила', 'петух', 'голубой',
    'гандон', 'говно', 'говнюк', 'говноед',
    'хуй', 'хуйло', 'хуесос', 'хуёвый', 'хуёво', 'хуяк', 'хуячить',
    'ебать', 'ебаный', 'ебанный', 'ебло', 'ебало', 'еблан', 'ебучий',
    'нахуй', 'нахер', 'нахрен', 'похуй', 'похер', 'похрен',
    'мудак', 'мудило', 'мудозвон',
    'залупа', 'залупоголовый',
    'дрочить', 'дрочка', 'дрочила',
    'шлюха', 'шалава', 'проститутка',
    'урод', 'уродина',
    'тварь', 'скотина',
    'мразь', 'гад', 'подонок',
    'лох', 'лошара', 'лохматый',
    'чмо', 'чмошник',
    'отстой', 'дерьмо', 'мерзость',
    # Часто используемые замены (латиница, символы и т.п.)
    'blyat', 'blyad', 'suka', 'pidor', 'gandon', 'huilo', 'huesos',
    'ebanyy', 'pizda', 'pzdets', 'xyu', 'xuy', 'xyilo', 'xyesos',
)

toxic_emoji = ['🤡', '💩']

reverso_word = {}
